"""Example Extender implementation."""

from typing import Any, Set

from mloda.core.abstract_plugins.function_extender import Extender, ExtenderHook


class MyExtender(Extender):
    """Example Extender - rename and customize for your use case."""

    def wraps(self) -> Set[ExtenderHook]:
        """Return the set of hooks this extender wraps."""
        return set()

    def __call__(self, func: Any, *args: Any, **kwargs: Any) -> Any:
        """Execute the wrapped function without modification."""
        return func(*args, **kwargs)
